#[repr(C)]pub struct DAffine2 {
pub matrix2: DMat2,
pub translation: DVec2,
}Expand description
A 2D affine transform, which can represent translation, rotation, scaling and shear.
Fields
matrix2: DMat2translation: DVec2Implementations
Sourceimpl DAffine2
impl DAffine2
Sourcepub const ZERO: DAffine2
pub const ZERO: DAffine2
The degenerate zero transform.
This transforms any finite vector and point to zero. The zero transform is non-invertible.
Sourcepub const IDENTITY: DAffine2
pub const IDENTITY: DAffine2
The identity transform.
Multiplying a vector with this returns the same vector.
Sourcepub const fn from_cols(x_axis: DVec2, y_axis: DVec2, z_axis: DVec2) -> DAffine2
pub const fn from_cols(x_axis: DVec2, y_axis: DVec2, z_axis: DVec2) -> DAffine2
Creates an affine transform from three column vectors.
Sourcepub fn from_cols_array(m: &[f64; 6]) -> DAffine2
pub fn from_cols_array(m: &[f64; 6]) -> DAffine2
Creates an affine transform from a [f64; 6] array stored in column major order.
Sourcepub fn to_cols_array(&self) -> [f64; 6]
pub fn to_cols_array(&self) -> [f64; 6]
Creates a [f64; 6] array storing data in column major order.
Sourcepub fn from_cols_array_2d(m: &[[f64; 2]; 3]) -> DAffine2
pub fn from_cols_array_2d(m: &[[f64; 2]; 3]) -> DAffine2
Creates an affine transform from a [[f64; 2]; 3]
2D array stored in column major order.
If your data is in row major order you will need to transpose the returned
matrix.
Sourcepub fn to_cols_array_2d(&self) -> [[f64; 2]; 3]
pub fn to_cols_array_2d(&self) -> [[f64; 2]; 3]
Creates a [[f64; 2]; 3] 2D array storing data in
column major order.
If you require data in row major order transpose the matrix first.
Sourcepub fn from_cols_slice(slice: &[f64]) -> DAffine2
pub fn from_cols_slice(slice: &[f64]) -> DAffine2
Creates an affine transform from the first 6 values in slice.
Panics
Panics if slice is less than 6 elements long.
Sourcepub fn write_cols_to_slice(self, slice: &mut [f64])
pub fn write_cols_to_slice(self, slice: &mut [f64])
Writes the columns of self to the first 6 elements in slice.
Panics
Panics if slice is less than 6 elements long.
Sourcepub fn from_scale(scale: DVec2) -> DAffine2
pub fn from_scale(scale: DVec2) -> DAffine2
Creates an affine transform that changes scale. Note that if any scale is zero the transform will be non-invertible.
Sourcepub fn from_angle(angle: f64) -> DAffine2
pub fn from_angle(angle: f64) -> DAffine2
Creates an affine transform from the given rotation angle.
Sourcepub fn from_translation(translation: DVec2) -> DAffine2
pub fn from_translation(translation: DVec2) -> DAffine2
Creates an affine transformation from the given 2D translation.
Sourcepub fn from_mat2(matrix2: DMat2) -> DAffine2
pub fn from_mat2(matrix2: DMat2) -> DAffine2
Creates an affine transform from a 2x2 matrix (expressing scale, shear and rotation)
Sourcepub fn from_mat2_translation(matrix2: DMat2, translation: DVec2) -> DAffine2
pub fn from_mat2_translation(matrix2: DMat2, translation: DVec2) -> DAffine2
Creates an affine transform from a 2x2 matrix (expressing scale, shear and rotation) and a translation vector.
Equivalent to
DAffine2::from_translation(translation) * DAffine2::from_mat2(mat2)
Sourcepub fn from_scale_angle_translation(
scale: DVec2,
angle: f64,
translation: DVec2,
) -> DAffine2
pub fn from_scale_angle_translation( scale: DVec2, angle: f64, translation: DVec2, ) -> DAffine2
Creates an affine transform from the given 2D scale, rotation angle (in radians) and
translation.
Equivalent to DAffine2::from_translation(translation) * DAffine2::from_angle(angle) * DAffine2::from_scale(scale)
Sourcepub fn from_angle_translation(angle: f64, translation: DVec2) -> DAffine2
pub fn from_angle_translation(angle: f64, translation: DVec2) -> DAffine2
Creates an affine transform from the given 2D rotation angle (in radians) and
translation.
Equivalent to DAffine2::from_translation(translation) * DAffine2::from_angle(angle)
Sourcepub fn to_scale_angle_translation(self) -> (DVec2, f64, DVec2)
pub fn to_scale_angle_translation(self) -> (DVec2, f64, DVec2)
Extracts scale, angle and translation from self.
The transform is expected to be non-degenerate and without shearing, or the output will be invalid.
Panics
Will panic if the determinant self.matrix2 is zero or if the resulting scale
vector contains any zero elements when glam_assert is enabled.
Sourcepub fn transform_point2(&self, rhs: DVec2) -> DVec2
pub fn transform_point2(&self, rhs: DVec2) -> DVec2
Transforms the given 2D point, applying shear, scale, rotation and translation.
Sourcepub fn transform_vector2(&self, rhs: DVec2) -> DVec2
pub fn transform_vector2(&self, rhs: DVec2) -> DVec2
Transforms the given 2D vector, applying shear, scale and rotation (but NOT translation).
To also apply translation, use Self::transform_point2() instead.
Sourcepub fn is_finite(&self) -> bool
pub fn is_finite(&self) -> bool
Returns true if, and only if, all elements are finite.
If any element is either NaN, positive or negative infinity, this will return
false.
Sourcepub fn abs_diff_eq(&self, rhs: DAffine2, max_abs_diff: f64) -> bool
pub fn abs_diff_eq(&self, rhs: DAffine2, max_abs_diff: f64) -> bool
Returns true if the absolute difference of all elements between self and rhs
is less than or equal to max_abs_diff.
This can be used to compare if two 3x4 matrices contain similar elements. It works
best when comparing with a known value. The max_abs_diff that should be used used
depends on the values being compared against.
For more see comparing floating point numbers.
Sourcepub fn inverse(&self) -> DAffine2
pub fn inverse(&self) -> DAffine2
Return the inverse of this transform.
Note that if the transform is not invertible the result will be invalid.
Sourcepub fn as_affine2(&self) -> Affine2
pub fn as_affine2(&self) -> Affine2
Casts all elements of self to f32.